@@ -110,7 +110,7 @@ class MediaCurl : public MediaNetworkCommonHandler
     };
 
   protected:
-//     /** Callback sending just an alive trigger to the UI, without stats (e.g. during metalink download). */
+    /** Callback sending just an alive trigger to the UI, without stats (e.g. during metalink download). */
     static int aliveCallback( void *clientp, double dltotal, double dlnow, double ultotal, double ulnow );
     /** Callback reporting download progress. */
     static int progressCallback( void *clientp, double dltotal, double dlnow, double ultotal, double ulnow );
@@ -126,11 +126,6 @@ class MediaCurl : public MediaNetworkCommonHandler
      * \throws MediaCurlSetOptException if there is a problem
      **/
     virtual void setupEasy();
-    /**
-     * concatenate the attach url and the filename to a complete
-     * download url
-     **/
-    Url getFileUrl(const Pathname & filename) const;
 
     /**
      * Evaluates a curl return code and throws the right MediaException
@@ -162,8 +157,6 @@ class MediaCurl : public MediaNetworkCommonHandler
     bool detectDirIndex() const;
 
   private:
-    long _curlDebug;
-
     std::string _currentCookieFile;
     static Pathname _cookieFile;
 
