@@ -116,7 +116,16 @@ namespace zypp
       if (! _target)
         ZYPP_THROW(Exception("Target not initialized."));
       return _target;
-     }
+    }
+
+    void ZYppImpl::changeTargetTo( Target_Ptr newtarget_r )
+    {
+      if ( _target && newtarget_r ) // bsc#1203760: Make sure the old target is deleted before a new one is created!
+        INT << "2 active targets at the same time must not happen!" << endl;
+      _target = newtarget_r;
+      ZConfig::instance().notifyTargetChanged();
+      resolver()->setDefaultSolverFlags( /*all_r*/false );  // just changed defaults
+    }
 
     void ZYppImpl::initializeTarget( const Pathname & root, bool doRebuild_r )
     {
@@ -126,11 +135,10 @@ namespace zypp
               MIL << "Repeated call to initializeTarget()" << endl;
               return;
           }
-
           _target->unload();
-
+          _target = nullptr;  // bsc#1203760: Make sure the old target is deleted before a new one is created!
       }
-      _target = new Target( root, doRebuild_r );
+      changeTargetTo( new Target( root, doRebuild_r ) );
       _target->buildCache();
     }
 
@@ -139,7 +147,7 @@ namespace zypp
       if (_target)
           _target->unload();
 
-      _target = nullptr;
+      changeTargetTo( nullptr );
     }
 
     //------------------------------------------------------------------------
